@@ -51,7 +51,7 @@ class SourceDevice:
         self.device_name = device_name
         self.site_name = site_name
 
-    @hostname.delete
+    @hostname.deleter
     def hostname(self):
         self.device_name = None
         self.site_name = None
